IDOS • Horní Polanka ➞ VŠB-TUO • Všechny jízdní řády • Vyhledání spojení
Author: CHAPS spol. s r.o.
Description: Spojení Horní Polanka » VŠB-TUO 15.10.2022
Keywords: idos, jízdní řády, doprava, vlaky, autobusy, mhd

#

Odkud Vybrat na mapě

Prohodit

Kam Vybrat na mapě

Datum: 15.10.2022 - Předchozí den +Následující den

Čas: 2:01 - O hodinu dříve +O hodinu později

- :Dřívější spojení
- ;Pozdější spojení

# Vymazat uložené údaje

smazat oblíbené položky

smazat historii hledání

smazat použité jízdní řády (přejde na úvodní stránku)

Vybrané údaje byly vymazány

- Vytisknout
- Sdílet

## 2:1615.10. so

Celkový čas 33 min, vzdálenost 11 km

### Bus 46

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 2:16

  Horní Polanka D 2

- 2:31

  Svinov,mosty õ D12

Přesun asi 3 min

### Tram 7

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 2:41

  Svinov,mosty õ= H1

- 2:49

  VŠB-TUO = 1

- Detaily spojení
- Vytisknout
- Sdílet(1)
- Zobrazit na mapě
- Přidat do Mých spojení

## 2:3815.10. so

Celkový čas 1 hod 11 min, vzdálenost 10 km

### Bus 76

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 2:38

  Horní Polanka D 1

- 2:39

  Polanka,střed D 1

Přesun asi 1 min

### Bus 76

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 3:18

  Polanka,střed D 2

- 3:30

  Svinov,mosty õ D12

Přesun asi 3 min

### Tram 7

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 3:41

  Svinov,mosty õ= H1

- 3:49

  VŠB-TUO = 1

- Detaily spojení
- Vytisknout
- Sdílet(1)
- Zobrazit na mapě
- Přidat do Mých spojení

## 3:3815.10. so

Celkový čas 46 min, vzdálenost 10 km

### Bus 76

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 3:38

  Horní Polanka D 1

- 3:39

  Polanka,střed D 1

Přesun asi 1 min

### Bus 76

H

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 3:56

  Polanka,střed D 2

- 4:08

  Svinov,mosty õ D12

Přesun asi 3 min

### Tram 8

Dopravce - DP Ostrava a.s., Dopravní Infocentrum Ostrava 597 608 508

- 4:16

  Svinov,mosty õ= H1

- 4:24

  VŠB-TUO = 1

- Detaily spojení
- Vytisknout
- Sdílet(1)
- Zobrazit na mapě
- Přidat do Mých spojení

- :Dřívější spojení
- ;Pozdější spojení

- Vytisknout
- Sdílet

## Vaše cesta

Upozornění
Na vybrané spojení nám dopravci umožňují prodat jízdenky jen na úseky:
Opravdu chcete odstranit toto spojení z košíku?

# Cestující

Přidat další cestující Uložit cestující

# Slevové průkazy

Uložit
Cesta ZPĚT
Přejete si vyhledat jízdenku na cestu ZPĚT?
Cesta ZPĚT

Datum odjezdu:

: - +

Čas odjezdu:

: - +

# Sdílení spojení Sdílení odjezdů/příjezdů Sdílení dráhy spoje Sdílení zastávkového JŘ

Poslat na e-mail Uložit jako PDF Přidat do kalendáře

### Trvalý odkaz na nalezená spojení

### Trvalý odkaz na nalezené spojení

### Trvalý odkaz na nalezený spoj

### Trvalý odkaz na nalezené odjezdy

### Trvalý odkaz na nalezené příjezdy

### Trvalý odkaz na zastávkový JŘ

Adresa právě vyhledaného spojení Adresa právě vyhledaných odjezdů Adresa právě vyhledaných příjezdů Adresa právě vyhledaných zastávkových JŘ
Adresa pro vyhledání spojení v aktuální datum a čas Adresa pro vyhledání odjezdů v aktuální datum a čas Adresa pro vyhledání příjezdů v aktuální datum a čas Adresa pro vyhledání zastávkových JŘ v aktuální datum

# Zaslat spojení e-mailem

E-mail příjemce

Zpráva pro příjemce je prázdná

# Datové omezení

## Najdete na iDNES.cz

#### Revue

### Zkazila jste mi entrée, káral Kotvald v úvodu recitálu vyrušující ženu

#### Ekonomika

### Těžká váha. Německý strop na plyn ohrožuje pozici českých firem

#### Zprávy

### Prezidentské volby: Kandidovat může každý čtyřicátník, prezident nebydlí na Hradě

#### OnaDnes

### Příběh Jardy: Dcera žije s celou rodinou u nás, pro mě tu už není místo

Moje spojení 1